# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .generation_info import GenerationInfo
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class MessageGenerationInspection(UniversalBaseModel):
    """
    Inspection data for message generation.
    """

    generation: GenerationInfo
    messages: typing.List[typing.Optional[str]] = pydantic.Field()
    """
    The messages that were generated
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
