# This file was auto-generated by Fern from our API Definition.

import typing

EventSourceDto = typing.Union[
    typing.Literal[
        "customer",
        "customer_ui",
        "human_agent",
        "human_agent_on_behalf_of_ai_agent",
        "ai_agent",
        "system",
    ],
    typing.Any,
]
