# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import pydantic
from .connection_kind_dto import ConnectionKindDto
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class GuidelineConnectionAddition(UniversalBaseModel):
    """
    Used to add connections between Guidelines.
    """

    source: str = pydantic.Field()
    """
    `id` of guideline that is source of this connection.
    """

    target: str = pydantic.Field()
    """
    `id` of guideline that is target of this connection.
    """

    kind: ConnectionKindDto

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
